/**
 *******************************************************************************
 * @file    tmpm3u6_vltd.c
 * @brief   This file provides API functions for VLTD driver. 
 * @version V2.0.2.3
 * @date    2014/04/23
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2019
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "tmpm3u6_vltd.h"

#if defined(__TMPM3U6_VLTD_H)
/** @addtogroup TX03_Periph_Driver
  * @{
  */
/** @defgroup VLTD
  * @brief VLTD driver modules
  * @{
  */

/** @defgroup VLTD_Private_Defines
  * @{
  */

#define VLTD_VDLVL_MASK         ((uint32_t)0xFFFFFFF9)

/** @} */
/* End of group VLTD_Private_Defines */

/** @defgroup VLTD_Exported_Functions
  * @{
  */

/**
  * @brief  Enable the operation of voltage detection.
  * @param  None
  * @retval None
  */
void VLTD_Enable(void)
{
    TSB_VD_CR_VDEN = 1U;
}

/**
  * @brief  Disable the operation of voltage detection.
  * @param  None
  * @retval None
  */
void VLTD_Disable(void)
{
    TSB_VD_CR_VDEN = 0U;
}

/**
  * @brief  Select for detection voltage.
  * @param  Voltage : detection voltage, which can be:
  *             VLTD_DETECT_VOLTAGE_38, VLTD_DETECT_VOLTAGE_41,
  *             VLTD_DETECT_VOLTAGE_44, VLTD_DETECT_VOLTAGE_46.
  * @retval None
  */
void VLTD_SetVoltage(uint32_t Voltage)
{
    uint32_t regval = TSB_VD->CR;

    /* Check the parameter */
    assert_param(IS_VLTD_DETECT_VOLTAGE(Voltage));

    regval &= VLTD_VDLVL_MASK;
    regval |= Voltage;
    TSB_VD->CR = regval;
}

/**
  * @brief  Get current power supply voltage status.
  * @param  None
  * @retval The status of current power supply voltage, which can be
  *         0 (Power supply voltage is higher than the detection voltage specified by VDLVL[1:0])
  *      or 1 (Power supply voltage is lower than the detection voltage specified by VDLVL[1:0]).
  */
uint32_t VLTD_GetStatus(void)
{
    return TSB_VD->SR;
}

/** @} */
/* End of group VLTD_Exported_Functions */
/** @} */
/* End of group VLTD */
/** @} */
/* End of group TX03_Periph_Driver */
#endif                          /* (__TMPM3U6_VLTD_H) */
