/**
 *******************************************************************************
 * @file    main.c
 * @brief   the application functions of ADC demo for the
 *          TOSHIBA 'TMPM3U6' Device Series
 * @version V0.121
 * @date    2019/07/19
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2019
 *******************************************************************************
 */


/* this demo is to show ADC function with software trigger on M3U6 board       */

/* Includes ------------------------------------------------------------------*/
#include "main.h"


ADC_Result result = { 0U };
WorkState adcState = BUSY;
uint32_t myResult = 0U;
uint8_t fdisplay = 0U;

int main()
{
    TMRB_InitTypeDef m_tmrb;

    m_tmrb.Mode = TMRB_INTERVAL_TIMER;
    m_tmrb.ClkDiv = TMRB_CLK_DIV_8;
    m_tmrb.TrailingTiming = TMRB_1MS;    /* periodic time is 1ms */
    m_tmrb.UpCntCtrl = TMRB_AUTO_CLEAR;
    m_tmrb.LeadingTiming = TMRB_1MS;     /* periodic time is 1ms */

    TMRB_Enable(TSB_TB0);
    TMRB_Init(TSB_TB0, &m_tmrb);
    NVIC_EnableIRQ(INTTB00_IRQn);
    TMRB_SetRunState(TSB_TB0, TMRB_RUN);

    hardware_init(UART_RETARGET);

    /* 1. set ADC clock */
    ADC_SetClk(ADC_HOLD_FIX, ADC_FC_DIVIDE_LEVEL_NONE);

    /* 2. select trigger and AD channel, this time we use sofeware trigger, */
    /*    the VR1 is connected to AIN0, remember to input with macro TRG_ENABLE() */
    ADC_SetSWTrg(ADC_REG0, TRG_ENABLE(ADC_AIN0));

    /* 3. to let ADC module work, we must disable low power mode */
    ADC_SetLowPowerMode(DISABLE);

    /* 4. enable ADC module */
    ADC_Enable();

    /* 5. now start ADC */
    ADC_Start(ADC_TRG_SW);

    while (1U) {
        /* check ADC module state */
        adcState = ADC_GetConvertState(ADC_TRG_SW);

        if (adcState == DONE) {
            /* read ADC result when it is finished */
            result = ADC_GetConvertResult(ADC_REG0);

            /* get the real ADC result without other information */
            myResult = result.Bit.ADResult;

            /* software trigger, need to trig it again */
            ADC_Start(ADC_TRG_SW);
        } else {
            /* Do nothing */
        }

        if(fdisplay == 1U){
            fdisplay = 0U;
            printf("\nAIN0 > 0x%03x",myResult);
        } else{
            /* Do nothing */
        }

    }
}

#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif
