/**
 *******************************************************************************
 * @file    CG.c
 * @brief   The driver functions of CG for the TOSHIBA 'TMPM3U6' Device Series 
 * @version V0.111
 * @date    2019/07/09
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2019
 *******************************************************************************
 */
/* Includes ------------------------------------------------------------------*/
#include "cg.h"
/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
#define CG_WUODR_EXT     ((uint16_t)0x0FFF)
#define CG_WUODR_PLL     ((uint16_t)0x01F4)
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Global variables ----------------------------------------------------------*/
/* external variables --------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
Result CG_EnableClkMulCircuit(void);
/* Private functions ---------------------------------------------------------*/

/* CG_SetSystem */
void CG_SetSystem(void)
{
    /* Set fgear = fc */
    CG_SetFgearLevel(CG_DIVIDE_1);
    /* Set fperiph to fgear */
    CG_SetPhiT0Src(CG_PHIT0_SRC_FGEAR);
    CG_SetPhiT0Level(CG_DIVIDE_1);
    /* Set SCOUT source */
    CG_SetSCOUTSrc(CG_SCOUT_SRC_PHIT0);
    /* Set port M as HOSC */
    CG_SetPortM(CG_PORTM_AS_HOSC);
    /* Set fosc source */
    CG_SetFoscSrc(CG_FOSC_OSC1);
    /* Enable low-speed oscillator */
    CG_SetFs(ENABLE);
    /* Set low power consumption mode sleep */
    CG_SetSTBYMode(CG_STBY_MODE_SLEEP);
    /* Set high-speed and low-speed oscillator to be enabled after releasing stop mode */
    CG_SetExitStopModeFosc(ENABLE);
    CG_SetExitStopModeFs(ENABLE);
    /* Set pin status in stop mode to "active" */
    CG_SetPinStateInStopMode(ENABLE);
    /* Set up pll and wait 200us for pll to warm up , set fc source to fpll */
    CG_EnableClkMulCircuit();
    /* Set system clock to fgear */
    CG_SetFsysSrc(CG_FSYS_SRC_FGEAR);
}

/* CG_NormalToSleep */
void CG_NormalToSleep(void)
{
    /* Set CG module: Normal ->Sleep mode */
    /* Add code here to disable modules (except CPU,RTC,I/O,CEC and RMC) if it has been enabled... */
    /* Then set system clock to fs */
    FunctionalState fs_st;
    fs_st = CG_GetFsState();
    if (fs_st == DISABLE) {
        CG_SetFs(ENABLE);
        CG_SetWarmUpTime(CG_WARM_UP_SRC_XT1, CG_WUODR_EXT);
        /* Start warm up */
        CG_StartWarmUp();
        /* Check whether warm up ends or not */
        while (CG_GetWarmUpState() == BUSY);
    } else {
        /* Do nothing */
    }

    CG_SetWarmUpTime(CG_WARM_UP_SRC_OSC1, CG_WUODR_EXT);
    /* Set RMC wake up system */
    CG_SetSTBYReleaseINTSrc(CG_INT_SRC_RMC_RX, CG_INT_ACTIVE_STATE_RISING, ENABLE);
    /* Enter sleep mode */
    __WFI();
}

/* CG_EnableClkMulCircuit */
Result CG_EnableClkMulCircuit(void)
{
    Result retval = ERROR;
    WorkState st = BUSY;
    retval = CG_SetPLL(ENABLE);
    if (retval == SUCCESS) {
        /* Set warm up time */
        CG_SetWarmUpTime(CG_WARM_UP_SRC_OSC1, CG_WUODR_PLL);
        CG_StartWarmUp();

        do {
            st = CG_GetWarmUpState();
        } while (st != DONE);

        retval = CG_SetFcSrc(CG_FC_SRC_FPLL);
    } else {
        /*Do nothing */
    }

    return retval;
}

/*********************************** END OF FILE ******************************/
