/**
 *******************************************************************************
 * @file    main.c
 * @brief   the application functions of CG_ModeSwitch demo for the 
 *          TOSHIBA 'TMPM3U6' Device Series
 * @version V0.112
 * @date    2019/07/09
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2019
 *******************************************************************************
 */
/* Includes ------------------------------------------------------------------*/
#include "main.h"
/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
#define TMRB_1MS   ((uint32_t)0x4E)
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Global variables ----------------------------------------------------------*/
/* external variables --------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/

/* Main function */
int main(void)
{
    SYSSTAT fSysSleep;
    TMRB_InitTypeDef myTMRB;

    /* Initialize system */
    CG_SetSystem();
    RMC_GPIOConfig(TSB_RMC0);

    /* UART initialization */
    hardware_init(UART_RETARGET);

    /* Disable interrupts */
    __disable_irq();

    myTMRB.Mode = TMRB_INTERVAL_TIMER;
    myTMRB.ClkDiv = TMRB_CLK_DIV_8;
    myTMRB.TrailingTiming = TMRB_1MS * 2U;
    myTMRB.UpCntCtrl = TMRB_AUTO_CLEAR;
    myTMRB.LeadingTiming = TMRB_1MS;

    /* Configure TB0 */
    TMRB_Enable(TSB_TB0);
    TMRB_Init(TSB_TB0, &myTMRB);

    /* Configure RMC */
    RMC_ChInit(TSB_RMC0);

    /* Enable RMCRX INT */
    CG_ClearINTReq(CG_INT_SRC_RMC_RX);
    CG_SetSTBYReleaseINTSrc(CG_INT_SRC_RMC_RX, CG_INT_ACTIVE_STATE_RISING, ENABLE);
    NVIC_ClearPendingIRQ(INTRMCRX_IRQn);
    NVIC_EnableIRQ(INTRMCRX_IRQn);
    __enable_irq();

    /* Initialize Variables */
    fTMRB0_INT = 0U;
    fSysSleep = WAKE;
    fRMCDone = BUSY;
    fRMCPress = RELEASE;
    printf("TMPM3U6 CG_ModeSwitch DEMO\r\n");

    for (;;) {
        if (fRMCDone == DONE) { /* RMC reception complete */
            RMC_SetRxCtrl(TSB_RMC0, DISABLE);   /* Stop RMC receiving */
            /* Get gAddress and gCommand */
            RMCRcv();

            switch (gRMC_Command) {
                /* Special keys: sleep -> normal */
            case SEVEN_KEY:    /* No break */
            case CH_UP:    /* No break */
            case VOL_UP:
                PrintCode(FORMAT, gRMC_Address, gRMC_Command);
                if (fSysSleep == SLEEP) {       /* Current state is sleep */
                    fSysSleep = WAKE;
                    printf("Wakeup from Sleep\r\n");

                } else {
                    /* Do nothing */
                }

                break;
                /* Special keys: normal -> sleep */
            case NINE_KEY:    /* No break */
            case VOL_DOWN:    /* No break */
            case CH_DOWN:
                if (fSysSleep == WAKE) {        /* Current state is normal */
                    fSysSleep = SLEEP;
                    PrintCode(FORMAT, gRMC_Address, gRMC_Command);
                    printf("Now, Going to Sleep\r\n");

                } else {
                    /* Do nothing */
                }

                break;
                /* Other keys */
            default:
                if (fSysSleep == WAKE) {        /* Current state is normal */
                    PrintCode(FORMAT, gRMC_Address, gRMC_Command);
                } else {
                    /* Do nothing */
                }

                break;
            }

            if (fSysSleep == SLEEP) {
                RMC_SetRxCtrl(TSB_RMC0, ENABLE);        /* Enable RMC receive */
                Delay(1000U);   /* Wait for all interrupts over */
                CG_NormalToSleep();
            } else {
                RMC_SetRxCtrl(TSB_RMC0, ENABLE);        /* Enable RMC receive */
            }
        } else {
            /* Do nothing */
        }
    }
}

/* PrintCode */
void PrintCode(char *ch, uint16_t add, uint32_t com)
{
    printf("%s: %02x %02x\r\n", ch, add, com);
}

/* Delay */
void Delay(uint32_t time)
{
    volatile uint32_t i = 0U;
    for (i = 0U; i < (time * 200U); ++i) {
        /* Do nothing */
    }
}

#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif
/*********************************** END OF FILE ******************************/
