/**
 *******************************************************************************
 * @file    rmc.c
 * @brief   The driver functions of RMC for the TOSHIBA 'TMPM3U6' Device Series 
 * @version V0.111
 * @date    2019/07/09
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2019
 *******************************************************************************
**/
/* Includes ------------------------------------------------------------------*/
#include "rmc.h"
/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
uint32_t gRMC_Command = 0U;
uint16_t gRMC_Address = 0U;
WorkState fRMCDone = BUSY;
RMCPRS fRMCPress = RELEASE;
IO_SFR32_u uRMCBuf;
/* Global variables ----------------------------------------------------------*/
/* external variables --------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/

/* GPIO_RMCConfig */
void RMC_GPIOConfig(TSB_RMC_TypeDef * RMCx)
{
    if (RMCx == TSB_RMC0) {
        TSB_PA_FR2_PA3F2 = 1U;
        TSB_PA_IE_PA3IE = 1U;
    } else {
        /* Do nothing */
    }
}

/* RMC_ChInit */
void RMC_ChInit(TSB_RMC_TypeDef * RMCx)
{
    RMC_InitTypeDef myRMC;

    /*RMC register set for TOSHIBA format */
    myRMC.LeaderPara.MaxCycle = RMC_MAX_CYCLE;
    myRMC.LeaderPara.MinCycle = RMC_MIN_CYCLE;
    myRMC.LeaderPara.MaxLowWidth = RMC_MAX_LOW_WIDTH;
    myRMC.LeaderPara.MinLowWidth = RMC_MIN_LOW_WIDTH;
    myRMC.LeaderPara.LeaderDetectionState = ENABLE;
    myRMC.LeaderPara.LeaderINTState = DISABLE;
    myRMC.FallingEdgeINTState = DISABLE;
    myRMC.SignalRxMethod = RMC_RX_IN_CYCLE_METHOD;
    myRMC.LowWidth = RMC_TRG_LOW_WIDTH;
    myRMC.MaxDataBitCycle = RMC_TRG_MAX_DATA_BIT_CYCLE;
    myRMC.LargerThreshold = RMC_LARGER_THRESHOLD;
    myRMC.SmallerThreshold = RMC_SMALLER_THRESHOLD;
    myRMC.InputSignalReversedState = DISABLE;
    myRMC.NoiseCancellationTime = RMC_NOISE_CANCELLATION_TIME;

    RMC_Enable(RMCx);
    RMC_Init(RMCx, &myRMC);
    /* RMC Reception enable */
    RMC_SetRxCtrl(RMCx, ENABLE);
}

/* RMCRcv */
void RMCRcv(void)
{
    fRMCDone = BUSY;

    gRMC_Address = uRMCBuf.byte[3];
    gRMC_Command = uRMCBuf.byte[1];
}

/*********************************** END OF FILE ******************************/
