/**
 *******************************************************************************
 * @file    tmpm3u6_int.c
 * @brief   all interrupt request functions definition of CG_ModeSwitch 
 *          for the TOSHIBA 'TMPM3U6' Device Series
 * @version V0.121
 * @date    2019/07/12
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2019
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "tmpm3u6_int.h"

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
uint16_t gRMCTimeOut = 0U;
uint8_t fTMRB0_INT = 0U;
/* external variables --------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/

/**
  * @brief  INTRMCRX_IRQHandler
  * @param  None
  * @retval None
  */
void INTRMCRX_IRQHandler(void)
{
    RMC_INTFactor myRMC_INTFactor;
    RMC_RxDataTypeDef myRMC_RxDataDef;
    RMC_LeaderDetection myRMC_LeaderDetection;
    myRMC_INTFactor = RMC_GetINTFactor(TSB_RMC0);

    /********************* FOR RMC_1 FORMAT  ***********************/
    if (myRMC_INTFactor.Bit.MaxDataBitCycle) {  /*Max data bit cycle detection interrupt factor */

        myRMC_LeaderDetection = RMC_GetLeader(TSB_RMC0);

        if (myRMC_LeaderDetection == RMC_LEADER_DETECTED) {     /*Leader has been detected */

            myRMC_RxDataDef = RMC_GetRxData(TSB_RMC0);
            if (myRMC_RxDataDef.RxDataBits == 0x20U) {  /*32 bits data received */

                uRMCBuf.reg = myRMC_RxDataDef.RxBuf1;   /* save the RMC data for print in main() */

                gRMCTimeOut = 0U;       /* reset time-out count */
                if (fRMCPress == RELEASE) {
                    fRMCPress = PRESS;
                } else {
                    /* Do nothing */
                }
            } else {
                if (fRMCPress) {        /* Repeat */
                    gRMCTimeOut = 0U;   /* reset time-out count */
                } else {
                    /* Do nothing */
                }
            }
        } else {
            /* Do nothing */
        }
    } else {
        /* Do nothing */
    }

    /* Detect RMC input TIMEOUT */
    if ((fRMCPress == PRESS) && (!fTMRB0_INT)) {  /* receive correct RMC data and TMBR is not running */
        fTMRB0_INT = 1U;        /* set TMRB0 INT flag */

        TMRB_SetRunState(TSB_TB0, TMRB_STOP);
        NVIC_EnableIRQ(INTTB00_IRQn);
        TMRB_SetRunState(TSB_TB0, TMRB_RUN);

    } else {
        /* Do nothing */
    }

    /* Clear RMC INT */
    CG_ClearINTReq(CG_INT_SRC_RMC_RX);
}

/**
  * @brief  INTTB00_IRQHandler
  * @param  None
  * @retval None
  */
void INTTB00_IRQHandler(void)
{
    if (++gRMCTimeOut > 300U) { /* No RMC input for more than 300ms */
        gRMCTimeOut = 0U;
        fTMRB0_INT = 0U;        /* Clear TMRB0 INT flag */

        fRMCPress = RELEASE;
        fRMCDone = DONE;        /* RMC reception finish */
        NVIC_DisableIRQ(INTTB00_IRQn);
    } else {
        /* Do nothing */
    }
}

