/**
 *******************************************************************************
 * @file    main.h
 * @brief   header file for main.c, included some address definition and
 *          function prototypes
 * @version V0.131
 * @date    2019/08/07
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2019
 *******************************************************************************
 */


#ifndef MAIN_H
#define MAIN_H

/* Includes ------------------------------------------------------------------*/
#include "tmpm3u6_cg.h"
#include "tmpm3u6_fc.h"
#include "led.h"
#include "sw.h"

/* Private define ------------------------------------------------------------*/
#define USER_BOOT_MODE          ((uint8_t)0x01)
#define NORMAL_MODE             ((uint8_t)0x00)

#if defined ( __CC_ARM   )      /* RealView Compiler */
#define CODE_START              ((void (*)(void))0x4265)
#define FLASH_API_ROM           ((uint32_t *)__Get_FLASHSWAP_Store_Base())
#elif defined ( __ICCARM__ )    /* IAR Compiler */
#define CODE_START              ((void (*)(void))0x42f5U)       /* code start address */
#define FLASH_API_ROM           ((uint32_t *)0x200)
#endif

#define DEMO_A_FLASH            ((uint32_t *)0x4000)
#define DEMO_B_FLASH            ((uint32_t *)0x8000)

#define RAM_BUFFER_START        ((uint32_t)0x20000000)
#define FLASH_API_RAM           ((uint32_t *)(RAM_BUFFER_START))
#define DEMO_A_RAM              ((uint32_t *)(RAM_BUFFER_START + 0x0800U))
#define DEMO_B_RAM              ((uint32_t *)(RAM_BUFFER_START + 0x1600U))

#define SIZE_FLASH_API          (0x400U)
#define SIZE_DEMO_A             (3500U)
#define SIZE_DEMO_B             (3500U)

#define PAGE_SIZE               (256U)


/* Private function prototypes -----------------------------------------------*/
void Copy_Routine(uint32_t * dest, uint32_t * source, uint32_t size);
uint8_t Flash_Swap(void);
uint8_t Mode_Judgement(void);
uint8_t Write_Flash(uint32_t * addr_dest, uint32_t * addr_source, uint32_t len);
void delay(uint32_t time);
void Status_Display(uint8_t SegChar);
#endif
/*************************** END OF FILE **************************************/
