/**
 *******************************************************************************
 * @file    main.c
 * @brief   the application functions of OFD demo for the
 *          TOSHIBA 'TMPM3U6' Device Series
 * @version V0.111
 * @date    2019/07/12
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2019
 *******************************************************************************
 */


#include "main.h"

/* declaration ---------------------------------------------------------------*/
void ChangeToEHOSC(void);
void Delay(void);
//#define DEMO2

/**
  * @brief  The main routine of ofd demo
  * @param  None
  * @retval None
  */  
int main(void)
{
    uint8_t OFDReset = 0U;
    CG_ResetFlag resetFlag = { 0U };
    LEDInit();
    resetFlag = CG_GetResetFlag();
    if (resetFlag.Bit.OFDReset == 0U) {
        /*Change to external oscillator */
        ChangeToEHOSC();
        /* OFD initial */
        OFD_SetRegWriteMode(ENABLE);
#ifdef DEMO2
        OFD_SetDetectionFrequency(OFD_HIGHER_COUNT_ABNORMAL, OFD_LOWER_COUNT_ABNORMAL);
#else
        OFD_SetDetectionFrequency(OFD_HIGHER_COUNT, OFD_LOWER_COUNT);
#endif
        OFD_Reset(ENABLE);
        OFD_Enable();
    } else {
        OFD_Disable();
        OFDReset = 1U;
    }
    while (1) {
        if (OFDReset == 1U) {
            LedOn(LED1);
            Delay();
            LedOff(LED1);
            Delay();
        } else {
            LedOn(LED0);
            Delay();
            LedOff(LED0);
            Delay();
        }
    }
}

/**
  * @brief  Change the system clock to external oscillator.
  * @param  None
  * @retval None
  */
void ChangeToEHOSC(void)
{
    /* Use the external oscillation */
    TSB_CG->OSCCR &= 0x000FFFFFUL;
    TSB_CG->OSCCR |= 0xFFF00000UL;      /*Set the warm up time WUODR[13:2]*/
    TSB_CG_OSCCR_HOSCON = 1U;   /*Set gpio port as X1/X2 for external oscillator */
    TSB_CG_OSCCR_XEN1 = 1U;     /*Enable external oscillator */
    TSB_CG_OSCCR_WUPSEL2 = 1U;
    TSB_CG_OSCCR_WUPSEL1 = 0U;  /*Select warm-up clock */
    TSB_CG_OSCCR_WUEON = 1U;    /*Start warm-up */    
    while (TSB_CG_OSCCR_WUEF) {}/* Warm-up */
    TSB_CG_OSCCR_OSCSEL = 1U;   /*Use the external oscillation */
    TSB_CG_OSCCR_XEN2 = 1U;     /*Enable internal oscillator for ofd */
}

/**
  * @brief  Delay.
  * @param  None
  * @retval None
  */
void Delay(void)
{
    uint32_t tmp;
    for (tmp = 0U; tmp < 0x5ffffU; tmp++);

}

/**
 * @brief Initialize the system
 * @param  none
 * @return none
 */
void SystemInit(void)
{
#if (WD_SETUP)                  /* Watchdog Setup */
  TSB_WD->MOD = WDMOD_Val;
  if (!TSB_WD_MOD_WDTE) {           /* If watchdog is to be disabled */
    TSB_WD->CR = WDCR_Val;
  } else {
    /* Do nothing */
  }
#endif
}

/**
  * @brief  Deal with the error parameter
  * @param  file: Pointer to the file where the error parameter locates
  * @param  line: Number of the line in which the error parameter locates
  * @retval None
  */
#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif
