/** 
 *******************************************************************************
 * @file    main.c
 * @brief   the application functions of TMRB_PPG demo for the TOSHIBA
 *          'TMPM3U6' Device Series 
 * @version V0.132
 * @date    2019/07/12
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2019
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "main.h"

/* declaration ---------------------------------------------------------------*/
void delay(uint32_t time);
void LeadingTiming_display(uint8_t leadingtiming);

/**
  * @brief  delay some time
  * @param  delay time
  * @retval None.
  */
void delay(uint32_t time)
{
    uint32_t i = 0U;
    for (i = 0U; i < time; i++) {
        /* Do nothing */
    }
}

/**
  * @brief  The main function of TMRB_PPG demo
  * @param  None
  * @retval None
  */
int main(void)
{
    uint8_t Rate = 0U;
    uint32_t LeadingTiming[5] = { 0x8CAU, 0x753U, 0x4E2U, 0x271U, 0xFAU };
    uint8_t leadingtiming_num[5] = { 10U, 25U, 50U, 75U, 90U };  /* leadingtiming number for LED display */
    uint8_t keyvalue;
    uint8_t keyflag = 0;

    TMRB_InitTypeDef m_tmrb;
    TMRB_FFOutputTypeDef PPGFFInital;

    /* UART & switch initialization */
    SW_Init();
    hardware_init(UART_RETARGET);

    /* Set PF1 as TB7OUT for PPG output */
    GPIO_SetOutput(GPIO_PF, GPIO_BIT_1);
    GPIO_EnableFuncReg(GPIO_PF, GPIO_FUNC_REG_1, GPIO_BIT_1);
    GPIO_SetPullUp(GPIO_PF, GPIO_BIT_1, ENABLE);

    m_tmrb.Mode = TMRB_INTERVAL_TIMER;
    m_tmrb.ClkDiv = TMRB_CLK_DIV_8;
    m_tmrb.UpCntCtrl = TMRB_AUTO_CLEAR;
    m_tmrb.TrailingTiming = TMRB7TIME;   /* T = 500us */
    m_tmrb.LeadingTiming = LeadingTiming[Rate];
    PPGFFInital.FlipflopCtrl = TMRB_FLIPFLOP_CLEAR;
    PPGFFInital.FlipflopReverseTrg = TMRB_FLIPFLOP_MATCH_TRAILINGTIMING | TMRB_FLIPFLOP_MATCH_LEADINGTIMING;

    TMRB_Enable(TSB_TB7);
    TMRB_Init(TSB_TB7, &m_tmrb);
    TMRB_SetFlipFlop(TSB_TB7, &PPGFFInital);
    TMRB_SetDoubleBuf(TSB_TB7, ENABLE, TMRB_WRITE_REG_SEPARATE);        /* enable double buffer */
    TMRB_SetRunState(TSB_TB7, TMRB_RUN);

    do {                        /* wait if switch is High */
        keyvalue = SW_Get(SW1);
        LeadingTiming_display(leadingtiming_num[0]);
    } while (GPIO_BIT_VALUE_1 == keyvalue);

    delay(0xFFFFU);              /* noise cancel */

    while (1) {
        do {                    /* wait if switch is Low */
            keyvalue = SW_Get(SW1);
            keyflag = 0;
        } while (GPIO_BIT_VALUE_0 == keyvalue);

        delay(0xFFFFU);          /* noise cancel */

        Rate++;
        if (Rate >= LEADINGTIMINGMAX) {  /* change leadingtiming rate */
            Rate = LEADINGTIMINGINIT;
        } else {
            /* Do nothing */
        }

        TMRB_ChangeLeadingTiming(TSB_TB7, LeadingTiming[Rate]);   /* switch is High again */

        do {                    /* wait if switch is High */
            keyvalue = SW_Get(SW1);
            if(keyflag == 0){
                LeadingTiming_display(leadingtiming_num[Rate]);
                keyflag = 1;
            } else {
                /* Do nothing */
            }
        } while (GPIO_BIT_VALUE_1 == keyvalue);

        delay(0xFFFFU);          /* noise cancel */
    }
}

void LeadingTiming_display(uint8_t leadingtiming)
{
    printf("PPG Output\r\n");
    printf("LeadingTiming:%d%%\r\n",leadingtiming);
}



/**
  * @brief  Deal with the error parameter
  * @param  file: Pointer to the file where the error parameter locates
  * @param  line: Number of the line in which the error parameter locates
  * @retval None
  */
#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif
