/** 
 *******************************************************************************
 * @file    main.c
 * @brief   The application functions of UART_FIFO_Demo for the
 *          TOSHIBA 'TMPM3U6' Device Series
 * @version V0.111
 * @date    2019/07/09
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2019
 *******************************************************************************
 */
#include "main.h"
#include "tmpm3u6_uart.h"
#include <stdio.h>

#define BufSize (sizeof(TxBuffer) / sizeof(*(TxBuffer)))
#define BufSize1 (sizeof(TxBuffer1) / sizeof(*(TxBuffer1)))

volatile uint8_t TxBuffer[] = "TMPM3U61";
volatile uint8_t RxBuffer[BufSize] = { 0U };
volatile uint8_t TxBuffer1[] = "TMPM3U62";
volatile uint8_t RxBuffer1[BufSize1] = { 0U };

const uint8_t NumToBeTx = BufSize - 1U;
const uint8_t NumToBeTx1 = BufSize1 - 1U;

volatile uint8_t TxCounter = 0U;
volatile uint8_t RxCounter = 0U;

volatile uint8_t TxCounter1 = 0U;
volatile uint8_t RxCounter1 = 0U;

UART_InitTypeDef myUART;

void ResetIdx(void);

int main(void)
{

    /* UART initialization */
    hardware_init(UART_RETARGET);

    /* Initialize system */
    SIO_Configuration(UART1);
    SIO_Configuration(UART2);

    myUART.BaudRate = (uint32_t)115200;
    myUART.DataBits = UART_DATA_BITS_8;
    myUART.StopBits = UART_STOP_BITS_1;
    myUART.Parity = UART_NO_PARITY;
    myUART.Mode =  UART_ENABLE_TX|UART_ENABLE_RX;
    myUART.FlowCtrl = UART_NONE_FLOW_CTRL;
        
    UART_Enable(UART1);
    UART_Init(UART1, &myUART);

    UART_Enable(UART2);
    UART_Init(UART2, &myUART);   
       
    UART_RxFIFOByteSel(UART1,UART_RXFIFO_RXFLEVEL);
    UART_RxFIFOByteSel(UART2,UART_RXFIFO_RXFLEVEL);
    
    UART_TxFIFOINTCtrl(UART1,ENABLE);
    UART_TxFIFOINTCtrl(UART2,ENABLE);

    UART_RxFIFOINTCtrl(UART1,ENABLE);
    UART_RxFIFOINTCtrl(UART2,ENABLE);

    UART_TRxAutoDisable(UART1,UART_RXTXCNT_AUTODISABLE);
    UART_TRxAutoDisable(UART2,UART_RXTXCNT_AUTODISABLE);
    
    UART_FIFOConfig(UART1,ENABLE); 
    UART_FIFOConfig(UART2,ENABLE); 
                
    UART_RxFIFOFillLevel(UART1,UART_RXFIFO4B_FLEVLE_4_2B);
    UART_RxFIFOFillLevel(UART2,UART_RXFIFO4B_FLEVLE_4_2B);

    UART_RxFIFOINTSel(UART1,UART_RFIS_REACH_EXCEED_FLEVEL);
    UART_RxFIFOINTSel(UART2,UART_RFIS_REACH_EXCEED_FLEVEL);
    
    UART_RxFIFOClear(UART1);
    UART_RxFIFOClear(UART2);    
    
    UART_TxFIFOFillLevel(UART1,UART_TXFIFO4B_FLEVLE_0_0B);
    UART_TxFIFOFillLevel(UART2,UART_TXFIFO4B_FLEVLE_0_0B);

    UART_TxFIFOINTSel(UART1,UART_TFIS_REACH_NOREACH_FLEVEL);
    UART_TxFIFOINTSel(UART2,UART_TFIS_REACH_NOREACH_FLEVEL);
    
    UART_TxFIFOClear(UART1); 
    UART_TxFIFOClear(UART2);
    
    NVIC_EnableIRQ(INTTX1_IRQn);
    NVIC_EnableIRQ(INTRX2_IRQn);
  
    NVIC_EnableIRQ(INTTX2_IRQn);
    NVIC_EnableIRQ(INTRX1_IRQn);
    while (1) {
       UART_SetTxData(UART1, (uint32_t) (TxBuffer[TxCounter++])); 
       UART_SetTxData(UART2, (uint32_t) (TxBuffer1[TxCounter1++]));
       while (RxCounter < NumToBeTx) {
            /* Do nothing */
      }
      
       while (RxCounter1 < NumToBeTx1) {
            /* Do nothing */
       } 
       
       printf("%s\n", RxBuffer1);
       printf("%s\n", RxBuffer);

       ResetIdx();
    }

}

void ResetIdx(void)
{
    uint8_t i = 0U;

    for (i = 0U; i <= RxCounter; i++) {
        RxBuffer[i] = 0U;
    }
    for (i = 0U; i <= RxCounter1; i++) {
        RxBuffer1[i] = 0U;
    }  
    TxCounter = 0U;
    RxCounter = 0U;
    
    TxCounter1 = 0U;
    RxCounter1 = 0U;

}

#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    printf("Err!");
    while (1) {
        __NOP();
    }
}
#endif
