/**
 *******************************************************************************
 * @file    tmpm3u6_uart_int.c
 * @brief   interrupt request functions definition of UART_FIFO_Demo for the
 *          TOSHIBA 'TMPM3U6' Device Series 
 * @version V0.111
 * @date    2019/07/12
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2019
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "tmpm3u6_uart_int.h"

extern const uint8_t NumToBeTx;
volatile extern uint8_t TxBuffer[];
volatile extern uint8_t RxBuffer[];
volatile extern uint8_t TxCounter;
volatile extern uint8_t RxCounter;

extern const uint8_t NumToBeTx1;
volatile extern uint8_t TxBuffer1[];
volatile extern uint8_t RxBuffer1[];
volatile extern uint8_t TxCounter1;
volatile extern uint8_t RxCounter1;


/**
  * @brief  The transmission interrupt request function of UART channel 0.
  * @param  None
  * @retval None
  */
void INTTX1_IRQHandler(void)
{
    volatile UART_Err err;

    if (TxCounter < NumToBeTx) {
        UART_SetTxData(UART1, TxBuffer[TxCounter++]);
    } else {
        err = UART_GetErrState(UART1);
    }
}


/**
  * @brief  The transmission interrupt request function of UART channel 1.
  * @param  None
  * @retval None
  */
void INTTX2_IRQHandler(void)
{
    volatile UART_Err err;

    if (TxCounter1 < NumToBeTx1) {
        UART_SetTxData(UART2, TxBuffer1[TxCounter1++]);
    } else {
        err = UART_GetErrState(UART2);
    }
}



/**
  * @brief  The reception interrupt request function of UART channel 0.
  * @param  None
  * @retval None
  */
void INTRX1_IRQHandler(void)
{
    volatile UART_Err err;

    err = UART_GetErrState(UART1);
    if (UART_NO_ERR == err) {
        RxBuffer[RxCounter++] = (uint8_t) UART_GetRxData(UART1);
    } else {
        /* do nothing */
    }
}

/**
  * @brief  The reception interrupt request function of UART channel 1.
  * @param  None
  * @retval None
  */
void INTRX2_IRQHandler(void)
{
    volatile UART_Err err;

    err = UART_GetErrState(UART2);
    if (UART_NO_ERR == err) {
        RxBuffer1[RxCounter1++] = (uint8_t) UART_GetRxData(UART2);
    } else {
        /* do nothing */
    }
}

