/** 
 *******************************************************************************
 * @file    main.c
 * @brief   the application functions of UART_Retarget demo for the TOSHIBA
 *          'TMPM3U6' Device Series
 * @version V0.111
 * @date    2019/07/12
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2019
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "main.h"

/**
  * @brief  main  function
  * @param  None
  * @retval None
  */
int main(void)
{
    uint8_t SW_info;
    uint8_t wait_SW0 = 1U;
    char TxBuffer[] = "TMPM3U6";

    /* Initialize system */

    /* UART & SW initialization */
    SW_Init();
    hardware_init(UART_RETARGET);

    while (1) {
        while (wait_SW0) {
            /* Read switch SW0 input */
            SW_info = SW_Get(SW_PORT);

            if (SW_info == 1U) {
                /* wait for TSW1 released */
                do {
                    wait_SW0 = 0U;
                    SW_info = SW_Get(SW_PORT);
                } while (SW_info != SWRELEASE);
            } else {
                /* do nothing */
            }
        }

        printf("%s\r\n", TxBuffer);     /* SIO0 send data */

        while (fSIOTxOK == NO) {        /* wait for UART0 finish send */
            /* do nothing */
        }
        fSIOTxOK = NO;
        wait_SW0 = 1U;
    }
}



/**
  * @brief  Deal with the error parameter
  * @param  file: Pointer to the file where the error parameter locates
  * @param  line: Number of the line in which the error parameter locates
  * @retval None
  */
#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif
