/**
 ******************************************************************************
 * @file     sw.c
 * @brief    SW driver for the TOSHIBA 'TMPM3U6' Device Series
 * @version  V0.100
 * @date     2019/07/09
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2019
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "sw.h"

/**
  * @brief  Initialize the GPIO to SW.
  *   SW0/4 connect with PG0.
  *   SW1/5 connect with PG1.
  *   SW2/6 connect with PG2.
  *   SW3/7 connect with PG3.
  * @param  None
  * @retval None
  */
void SW_Init(void)
{
    GPIO_SetPullDown(GPIO_PG, GPIO_BIT_0 | GPIO_BIT_1 | GPIO_BIT_2 | GPIO_BIT_3, ENABLE);
    GPIO_SetInput(GPIO_PG,  GPIO_BIT_0 | GPIO_BIT_1 | GPIO_BIT_2 | GPIO_BIT_3);
}

/**
  * @brief  Get SW Value.
  * @param  sw: SW number
  *   This parameter can be from SW0 ~ SW7.
  * @retval SW value.
  */
uint8_t SW_Get(uint8_t sw)
{
    uint8_t tmp = 0U;
    switch (sw) {
    case SW0:
        if (GPIO_ReadDataBit(GPIO_PG, GPIO_BIT_0) == 0U) {
            tmp = 1U;
        } else {
            /*Do nothing */
        }
        break;
    case SW1:
        if (GPIO_ReadDataBit(GPIO_PG, GPIO_BIT_1) == 0U) {
            tmp = 1U;
        } else {
            /*Do nothing */
        }
        break;
    case SW2:
        if (GPIO_ReadDataBit(GPIO_PG, GPIO_BIT_2) == 0U) {
            tmp = 1U;
        } else {
            /*Do nothing */
        }
        break;
    case SW3:
        if (GPIO_ReadDataBit(GPIO_PG, GPIO_BIT_3) == 0U) {
            tmp = 1U;
        } else {
            /*Do nothing */
        }
        break;
    default:
        break;
    }
    
    return tmp;
}
