/** 
 *******************************************************************************
 * @file    uart.c
 * @brief   the application functions of UART_Retarget demo for the TOSHIBA
 *          'TMPM3U6' Device Series 
 * @version V0.122
 * @date    2019/07/26
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2019
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "uart.h"

/* Private define ------------------------------------------------------------*/
char gSIOTxBuffer[BUFFER_SIZE] = { 0 };
volatile uint8_t gSIORdIndex = 0U;
volatile uint8_t gSIOWrIndex = 0U;
uint8_t fSIO_INT = 0U;
uint8_t fSIOTxOK = NO;

/**
  * @brief  INTTX0 Interrupt Service Routine.
  * @param  None
  * @retval None
  */
void INTTX0_IRQHandler(void)
{
    uint8_t tmp = 0U;

    tmp = gSIOWrIndex;
    if (gSIORdIndex < tmp) {    /* Buffer is not empty */
        UART_SetTxData(UART_RETARGET, (uint32_t) gSIOTxBuffer[gSIORdIndex++]);  /* Send data */
        fSIO_INT = SET;                 /* SIO INT is enable */
    } else {
        /* Disable SIO0 INT */
        fSIO_INT = CLEAR;
        NVIC_DisableIRQ(RETARGET_INT);
        fSIOTxOK = YES;
    }
    if (gSIORdIndex >= tmp) {   /* Reset buffer index */
        gSIOWrIndex = CLEAR;
        gSIORdIndex = CLEAR;
    } else {
        /* Do nothing */
    }
}

/**
  * @brief  SIO Configuration.
  * @param  SIO channel
  * @retval None
  */
void SIO_Configuration(TSB_SC_TypeDef * SCx)
{
    if (SCx == UART0) {
        GPIO_SetOutputEnableReg(GPIO_PE, GPIO_BIT_0, ENABLE);
        GPIO_EnableFuncReg(GPIO_PE, GPIO_FUNC_REG_1, GPIO_BIT_0);
        GPIO_EnableFuncReg(GPIO_PE, GPIO_FUNC_REG_1, GPIO_BIT_1);
        GPIO_SetInputEnableReg(GPIO_PE, GPIO_BIT_1, ENABLE);
        GPIO_SetPullUp(GPIO_PE, GPIO_BIT_1, ENABLE);
        GPIO_SetPullUp(GPIO_PE, GPIO_BIT_0, ENABLE);
    } else if (SCx == UART1) {
        GPIO_SetOutputEnableReg(GPIO_PA, GPIO_BIT_5, ENABLE);
        GPIO_EnableFuncReg(GPIO_PA, GPIO_FUNC_REG_1, GPIO_BIT_5);;
        GPIO_EnableFuncReg(GPIO_PA, GPIO_FUNC_REG_1, GPIO_BIT_6);;
        GPIO_SetInputEnableReg(GPIO_PA, GPIO_BIT_6, ENABLE);
        GPIO_SetPullUp(GPIO_PA, GPIO_BIT_6, ENABLE);
        GPIO_SetPullUp(GPIO_PA, GPIO_BIT_5, ENABLE);
    } else if (SCx == UART2) {
        GPIO_SetOutputEnableReg(GPIO_PD, GPIO_BIT_5, ENABLE);
        GPIO_EnableFuncReg(GPIO_PD, GPIO_FUNC_REG_1, GPIO_BIT_5);
        GPIO_EnableFuncReg(GPIO_PD, GPIO_FUNC_REG_1, GPIO_BIT_6);
        GPIO_SetInputEnableReg(GPIO_PD, GPIO_BIT_6, ENABLE);
        GPIO_SetPullUp(GPIO_PD, GPIO_BIT_6, ENABLE);
        GPIO_SetPullUp(GPIO_PD, GPIO_BIT_5, ENABLE);
    } else if (SCx == UART3) {
        GPIO_SetOutputEnableReg(GPIO_PF, GPIO_BIT_5, ENABLE);
        GPIO_EnableFuncReg(GPIO_PF, GPIO_FUNC_REG_1, GPIO_BIT_5);
        GPIO_EnableFuncReg(GPIO_PF, GPIO_FUNC_REG_1, GPIO_BIT_6);
        GPIO_SetInputEnableReg(GPIO_PF, GPIO_BIT_6, ENABLE);
        GPIO_SetPullUp(GPIO_PF, GPIO_BIT_6, ENABLE);
        GPIO_SetPullUp(GPIO_PF, GPIO_BIT_5, ENABLE);
    } else if (SCx == UART4) {
        GPIO_SetOutputEnableReg(GPIO_PC, GPIO_BIT_5, ENABLE);
        GPIO_EnableFuncReg(GPIO_PC, GPIO_FUNC_REG_1, GPIO_BIT_5);
        GPIO_EnableFuncReg(GPIO_PC, GPIO_FUNC_REG_1, GPIO_BIT_6);
        GPIO_SetInputEnableReg(GPIO_PC, GPIO_BIT_6, ENABLE);
        GPIO_SetPullUp(GPIO_PC, GPIO_BIT_6, ENABLE);
        GPIO_SetPullUp(GPIO_PC, GPIO_BIT_5, ENABLE);
    } else {
        /*  Do Nothing */
    }
}

/**
  * @brief  SIO Configuration Initialize the uart port (SIO0).
  * @param  None
  * @retval None
  */
void SIO_ChInit(void)
{
    UART_InitTypeDef myUART;

    /* Configure SIO0 for reception */
    UART_Enable(UART_RETARGET);
    myUART.BaudRate = 115200;          /* Baud rate = 115200 */
    myUART.DataBits = UART_DATA_BITS_8; /* No handshake, 8-bit data, clock by baud rate generator */
    myUART.StopBits = UART_STOP_BITS_1; /* 1-bit stop, LSB,  W-buff enable */
    myUART.Parity = UART_NO_PARITY;
    myUART.Mode = UART_ENABLE_TX;
    myUART.FlowCtrl = UART_NONE_FLOW_CTRL;
    UART_Init(UART_RETARGET, &myUART);
}

/**
  * @brief  Send character by SIO0
  * @param  Character to be sent
  * @retval Character to be sent
  */
uint8_t send_char(uint8_t ch)
{
    uint8_t tmp = 0U;

    do {
        tmp = gSIOWrIndex;
    } while (gSIORdIndex != tmp);   /* wait for finishing sending */

    gSIOTxBuffer[gSIOWrIndex++] = ch;           /* Fill TxBuffer */
    if (fSIO_INT == CLEAR) {                    /* If SIO INT disable, enable it */
        fSIO_INT = SET;                         /* Set SIO INT flag */
        UART_SetTxData(UART0, gSIOTxBuffer[gSIORdIndex++]);
        NVIC_EnableIRQ(RETARGET_INT);
    } else {
        /* do nothing */
    }
    return ch;
}

/**
  * @brief  SIO0 Init.
  * @param  SCx
  * @retval None
  */
void hardware_init(TSB_SC_TypeDef * SCx)
{
    /* Initialize system */
    SIO_Configuration(SCx);
    SIO_ChInit();
    /* enable retarget Channel TX interrupt */
    NVIC_EnableIRQ(RETARGET_INT);

}

/*********************************** END OF FILE ******************************/
